#include "stdafx.h"
#include <atlstr.h>
#include "ConfigXmlParser.h"
#define TIXML_USE_STL
#include "tinyxml.h"
#include "tipconst.h"
#include <atlpath.h>
#include "XMLUtil.h"
#include "XMLDataProvider.h"


namespace tipcommon
{
	BOOL ConfigXmlParser::GetURL(LPCTSTR target, LPCTSTR configxml_filename, Element::Type elementType/* LPCTSTR elementname*/, TCHAR* url, int urllen, BOOL bIncludePath, Locale::Type locale)
	{
		const TCHAR RESOURCE_ELEMENT_NAME[] = _T("resource");
		const TCHAR VERSION_ELEMENT_NAME[] = _T("version");
		const TCHAR SERVERINFO_ELEMENT_NAME[] = _T("updaterinfo");

		TiXmlDocument xmlDoc;
		CString xmlPath;
		if (bIncludePath)
		{
			xmlPath = configxml_filename;
		}
		else
		{
			TCHAR path[tipbase::MAXPATH] = {0, };
			GetCurrentDirectoryW(tipbase::MAXPATH, path);			
			xmlPath = path;
			xmlPath += '\\';
			xmlPath += configxml_filename;
		}

		USES_CONVERSION;
		if (FALSE == xmlDoc.LoadFile(T2A(xmlPath)))
			return FALSE;

		TiXmlElement* pElement = xmlDoc.FirstChildElement("root");
		if(pElement == NULL)	return NULL;

		// Search Locale
		TCHAR LocalAttrName[10] = {0, };
		TCHAR LocaleName[10] = {0, };
		switch(locale)
		{
		case Locale::Korean:
			_tcscpy_s(LocaleName, 10, _T("ko-KR"));
			break;
		case Locale::English:
			_tcscpy_s(LocaleName, 10, _T("en-US"));
			break;
		case Locale::Japanese:
			_tcscpy_s(LocaleName, 10, _T("ja-JP"));
			break;
		case Locale::Chinese:
			_tcscpy_s(LocaleName, 10, _T("zh-CN"));
			break;
		default:
			_tcscpy_s(LocaleName, 10, _T("ko-KR"));
			break;
		}

		pElement = pElement->FirstChildElement("locale");
		if (!pElement)
			return FALSE;

		BOOL bFindElement = FALSE;
		while(!bFindElement)
		{
			XMLUtil::GetAttrValue(pElement, "id", LocalAttrName, 10);
			if (_tcsicmp(LocaleName, LocalAttrName) == 0)
				break;

			pElement = pElement->NextSiblingElement("locale");
			if (!pElement)
				return FALSE;
		}

		pElement = pElement->FirstChildElement((CStringA)target);
		if (pElement == NULL)
			return FALSE; 

		LPCTSTR elementname = NULL;
		switch(elementType)
		{
		case Element::ResourceFileName:
			elementname = RESOURCE_ELEMENT_NAME;
			break;
		case Element::Version:
			elementname = VERSION_ELEMENT_NAME;
			break;
		case Element::ServerInfo:
			elementname = SERVERINFO_ELEMENT_NAME;
			break;
		}
		if (elementname == NULL)
			return FALSE;

		//TCHAR text[tipbase::MAXSTEXT] = {0, };
		if (FALSE == XMLUtil::GetValue(pElement, T2A(elementname), url, urllen))
			return FALSE;

		return TRUE;
	}
};